// Add special assembly references to be parsed by ACT here.  ACT will always add itself as a reference.
// Example:  (Keep the // commenting in actual use)  
// reference:System.dll
// reference:Microsoft.VisualBasic.dll

using System;
using System.Reflection;
using Advanced_Combat_Tracker;
using System.Windows.Forms;
using Microsoft.VisualBasic;

// ACT will parse these assembly attributes to show plugin info in the same way it would if it were a DLL
[assembly: AssemblyTitle("Mini Parse Name Hankaku Format")]
[assembly: AssemblyDescription("Mini Parse Name to Hankaku")]
[assembly: AssemblyVersion("1.0.0.1")]

namespace ACT_Plugin
{
    public class Name_Label_Plugin : IActPluginV1 // To be loaded by ACT, plugins must implement this interface
    {
        Label statusLabel;	// Handle for the status label passed by InitPlugin()

        int START_SIZE = 5;
        int END_SIZE = 15;

        public void InitPlugin(TabPage pluginScreenSpace, Label pluginStatusText)
        {
            statusLabel = pluginStatusText;
            statusLabel.Text = "Plugin started";
            Label lbl = new Label();
            lbl.Location = new System.Drawing.Point(8, 8);
            lbl.AutoSize = true;
            lbl.Text = "Nothing to display.";
            pluginScreenSpace.Controls.Add(lbl);

            for (int i = START_SIZE; i <= END_SIZE; i++)
            {
                setNameToHankaku(i);
            }

            CombatantData.ExportVariables.Add(
                "damege_format",
                new CombatantData.TextExportFormatter("damege_format", "Damege Format", "Damage Custom Format ", (data, extra) =>
                {
                    return String.Format("{0, 6}", data.GetColumnByName("Damage"));
                }));

            CombatantData.ExportVariables.Add(
                "damege%_format",
                new CombatantData.TextExportFormatter("damege%_format", "Damege % Format", "Damage % Custom Format ", (data, extra) =>
                {
                    return String.Format("{0, 3}", data.GetColumnByName("Damage%"));
                }));

            CombatantData.ExportVariables.Add(
                "encdps_format",
                new CombatantData.TextExportFormatter("encdps_format", "encdps Format", "encdps Custom Format ", (data, extra) =>
                {
                    return String.Format("{0, 6}", data.GetColumnByName("EncDPS"));
                }));

            EncounterData.ExportVariables.Add(
                "enemy",
                new EncounterData.TextExportFormatter("enemy", "enemy", "strong enemy name", (data, SelectiveAllies, extra) =>
                {
                    string s = data.GetStrongestEnemy(ActGlobals.charName);
                    if (s.IndexOf("(") != -1) {
                        return s.Substring(s.IndexOf("("));
                    }
                    else
                    {
                        return s;
                    }
                }));
                
            ActGlobals.oFormActMain.ValidateLists();
            statusLabel.Text = "Plugin Inited.";
        }

        public void DeInitPlugin()  // You must unsubscribe to any events you use
        {
            for (int i = START_SIZE; i <= END_SIZE; i++)
            {
                CombatantData.ExportVariables.Remove("nameToHankaku" + i);
            }

            CombatantData.ExportVariables.Remove("damege_format");
            CombatantData.ExportVariables.Remove("damege%_format");
            CombatantData.ExportVariables.Remove("encdps_format");
            EncounterData.ExportVariables.Remove("enemy");

            statusLabel.Text = "Plugin exited";
        }

        public void setNameToHankaku(int n)
        {
            CombatantData.ExportVariables.Add(
                "nameToHankaku" + n,
                new CombatantData.TextExportFormatter("nameToHankaku" + n, "Name to Hankaku" + n, "Name to Hankaku", (data, extra) =>
                {
                    string s = data.GetColumnByName("Name");
                    if (s.StartsWith("K[_"))
                    {
                        s = "" + s.Substring(s.IndexOf("("));
                    }
                    else if (s.StartsWith("^C^"))
                    {
                        s = "" + s.Substring(s.IndexOf("("));
                    }
                    else if (s.StartsWith("Ct[g"))
                    {
                        s = "" + s.Substring(s.IndexOf("("));
                    }
                    else if (s.StartsWith("tFA["))
                    {
                        s = Strings.StrConv(s.Substring(s.IndexOf("E") + 1), VbStrConv.Narrow, 0x411);
                    }

                    if (s.Length > n)
                    {
                        return s.Substring(0, n).Trim();
                    }
                    else
                    {
                        return s.Trim();
                    }

                }));
        }
    }
}
